from .variable import *
import requests
import json

class chat:
    def all_chat_list(self,debug=False)->dict:
        res = requests.get(f"{url}/be/api/v2/chat", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)
    def chat_list(self,limit:int,debug=False)->dict:
        res = requests.get(f"{url}/be/api/v2/chat?type=character&limit={limit}", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)
    def chat_log(self,room_id :str,limit:int,debug=False)->dict:
        res = requests.get(f"{url2}/terry/api/v2/chat-room/{room_id}/messages?limit={limit}", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)
    def send_chat(self,room_id:str,message:str,isSuperMode:bool=False,debug=False)->dict:
        data = {"message":message,"reroll":False,"images":[],"isSuperMode":isSuperMode}
        res_send = requests.post(f"{url2}/terry/characters/chat/{room_id}/message",headers=self.cookie,json=data)
        if res_send.status_code != 201 and debug is False:
            raise Exception(res_send.status_code)
        json_res = json.loads(res_send.text)
        res_recieve = requests.get(f"{url2}/terry/characters/chat/{room_id}/message/{json_res["data"]}",headers=self.cookie)
        return res_recieve.text


from .variable import *
import requests
import json

class feed:
    def ranking(self,limit:int,period="daily",debug=False)->dict:
        res = requests.get(f"{url}/be/characters/ranking?limit={limit}&period={period}", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)


from wrtn import wrtn

client = wrtn(token='eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjY3NTg3NDQ3ODBkYzEwMWQxMzY4ODUxNyIsImVtYWlsIjoic2lsbG8xNTQyNjVAZ21haWwuY29tIiwid3J0blVpZCI6IjhGZGJCcmg3OGFZLUdHS09NMGROTnpoTCIsImlzc3VlciI6IndydG4iLCJpYXQiOjE3MzU0OTc0MzIsImV4cCI6MTczNTUwMTAzMn0.kKuql7T-uR6T-qYTVnioqNN4iFX76JBmbfM9ToV4tZQ')

print(client.chat.send_chat(client,message="안녕2",room_id="6771460d7f21ad8d290923bb0",isSuperMode=False))


#메인 클레스
class Wrtn:
    # 유저정보클레스
    from .user import user
    # 채팅클레스
    from .chat import chat
    # 피드클레스
    from .feed import feed
    # 챗봇제작클레스
    from .charmaker import charmaker
    def __init__(self,token:str):
        self.cookie = {f"Authorization": f"Bearer {token}"}


from .variable import *
import requests
import json

class user:
    def direct_info(self,debug=False):
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)
    def nickname(self,debug=False):
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['name']
    def uid(self,debug=False):
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['wrtnUid']
    def _id(self,debug=False):
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['_id']
    def marketingAccountTerm(self,debug=False):
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['marketingTerm']
    def isNewbie(self,debug=False):
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['isNewbie']



from wrtn import wrtn

client = wrtn(token='<TOKEN>')

data = {
            "name":"테스트7",
            "description":"테스트5",
            "profileImageUrl":"<이미지url>",
            "model":"sonnet",
            "initialMessages":["테스트5"],
            "characterDetails":"테스트5",
            "replySuggestions":["안녕 테스트5! 어떻게 지내?","테스트5, 여기서 뭐하고 있었어? 뭔가 재밌는 일이 생겼어?","오, 테스트5! 요즘 어떤 일들이 있었는지 이야기 좀 해줘, 궁금해!"],
            "chatExamples":[],
            "situationImages":[],
            "categoryIds":["65e809f21a9eea7b2f660937"],
            "tags":[],
            "visibility":"public",
            "promptTemplate":"simulation",
            "isCommentBlocked":False,
            "defaultStartingSetName":"기본 설정",
            "startingSets":[],
            "keywordBook":[{
                "keywords":["테스트"],
                "prompt":"테스트5",
                "name":"키워드 노트 1"
            }
            ]
        }

print(client.charmaker.modify_char(client,data,char_id="6761541db6ecfa71fbf8e414"))


from wrtn import wrtn

client = wrtn(token='<TOKEN>')

print(client.chat.all_chat_list(client))
print(client.chat.send_chat(client,message="안녕",room_id="<채팅방id>",isSuperMode=False))
print(client.chat.chat_log(client,room_id="<room_id>",limit=10))

